==> jc-smjt-client-1.0.3-sources.jar: com/xforceplus/ultraman/app/jcsmjt/controller/BusinessBillFeignApi.java <==
package com.xforceplus.ultraman.app.jcsmjt.controller;


/**
 * 业务单表feign客户端
 *
 * @author ultraman
 * @date 2021-12-02
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jcsmjt.entity.BusinessBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-smjt")
public interface BusinessBillFeignApi {

  /**
   * 通过id查询业务单表
   * @param  id
   * @return R
   */
  @GetMapping("/businessBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增业务单表
   * @param businessBill 业务单表
   * @return R
   */
  @PostMapping("/businessBill/add")
  public R save(@RequestBody BusinessBill businessBill);

  /**
   * 修改业务单表
   * @param businessBill 业务单表
   * @return R
   */
  @PostMapping("/businessBill/update")
  public R updateById(@RequestBody BusinessBill businessBill);

  /**
   * 通过id删除业务单表
   * @param  id
   * @return R
   */
  @DeleteMapping("/businessBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-smjt-client-1.2.10-sources.jar: com/xforceplus/ultraman/app/jcsmjt/controller/BusinessBillFeignApi.java <==
package com.xforceplus.ultraman.app.jcsmjt.controller;


/**
 * 结算单表feign客户端
 *
 * @author ultraman
 * @date 2021-12-21
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jcsmjt.entity.BusinessBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-smjt")
public interface BusinessBillFeignApi {

  /**
   * 通过id查询结算单表
   * @param  id
   * @return R
   */
  @GetMapping("/businessBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增结算单表
   * @param businessBill 结算单表
   * @return R
   */
  @PostMapping("/businessBill/add")
  public R save(@RequestBody BusinessBill businessBill);

  /**
   * 修改结算单表
   * @param businessBill 结算单表
   * @return R
   */
  @PostMapping("/businessBill/update")
  public R updateById(@RequestBody BusinessBill businessBill);

  /**
   * 通过id删除结算单表
   * @param  id
   * @return R
   */
  @DeleteMapping("/businessBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}
